@@ -14,7 +14,7 @@ from tiddlyweb.config import config
 from tiddlyweb.store import Store
 from tiddlyweb.model.bag import Bag
 
-from tiddlywebplugins.instancer.util import spawn
+from tiddlywebplugins.imaker import spawn
 
 
 instance_dir = 'test_instance'
@@ -27,36 +27,20 @@ def setup_module(module):
     except:
         pass
 
-    instance_tiddlers = config['instance_tiddlers']
-    for bag, uris in instance_tiddlers.items():
-        # ensure that HTTP URLs are not used
-        # XXX: this is a temporary workaround until we have proper tests
-        for uri in uris:
-            if uri.startswith('http'):
-                raise ValueError(
-                        'must not use HTTP URLs; use cacher for local copies')
-        # adjust relative paths to account for instancer's chdir operation
-        # XXX: obsolete?
-        instance_tiddlers[bag] = [
-            uri.replace('file:./', 'file:../') for uri in uris
-        ]
-
 
 class TestInstance(object):
 
     def setup_method(self, module):
-        env = {'tiddlyweb.config': config}
-        self.store = Store(config['server_store'][0],
-                config['server_store'][1], environ=env)
-
-    def teardown_method(self, module):
-        os.chdir('..')
-        rmtree(instance_dir)
+        try:
+            rmtree(instance_dir)
+        except:
+            pass
+        self.env = {'tiddlyweb.config': config}
 
     def test_create_tiddlywebwiki_instance(self):
         spawn(instance_dir, config, instance_module)
 
-        contents = _get_file_contents('../%s/tiddlywebconfig.py'
+        contents = _get_file_contents('%s/tiddlywebconfig.py'
                 % instance_dir)
 
         assert "'system_plugins': ['tiddlywebwiki']" in contents
@@ -64,11 +48,14 @@ class TestInstance(object):
 
     def test_create_bag_policies(self):
         spawn(instance_dir, config, instance_module)
+        os.chdir(instance_dir)
+        store = Store(config['server_store'][0],
+                config['server_store'][1], environ=self.env)
 
         bag = Bag('system')
-        system_policy = self.store.get(bag).policy
+        system_policy = store.get(bag).policy
         bag = Bag('common')
-        common_policy = self.store.get(bag).policy
+        common_policy = store.get(bag).policy
 
         assert system_policy.read == []
         assert system_policy.write == ['R:ADMIN']
@@ -83,6 +70,7 @@ class TestInstance(object):
         assert common_policy.manage == ['R:ADMIN']
         assert common_policy.accept == []
         assert common_policy.delete == []
+        os.chdir('..')
 
 
 def _get_file_contents(filepath):
